# Tasty

Tasty is a full featured, efficient tagging engine accessible entirely through a REST interface. You can think of it as del.icio.us but designed to be embedded within an application (or multiple applications). Since the interface is just REST, it can be embedded in an application written in any programming language (as long as that language supports basic HTTP). Tasty is written in python, using the TurboGears framework.

- Requirements
- Installation
- Tag Model
- REST Interface
- Client Implementations
- Sites

email me at anders@columbia.edu with questions/comments. if there's enough interest, i'll set up a mailing list.